@@ -2,10 +2,12 @@ from collections import defaultdict
 import six
 import datetime
 import sqlalchemy as sa
-from sqlalchemy.orm import defer
+from sqlalchemy.orm import defer, RelationshipProperty
+from sqlalchemy.orm.attributes import set_committed_value
 from sqlalchemy.orm.mapper import Mapper
-from sqlalchemy.orm.query import _ColumnEntity, Query
 from sqlalchemy.orm.properties import ColumnProperty
+from sqlalchemy.orm.query import _ColumnEntity, Query
+from sqlalchemy.orm.session import object_session
 from sqlalchemy.orm.util import AliasedInsp
 from sqlalchemy.schema import MetaData, Table, ForeignKeyConstraint
 from sqlalchemy.sql.expression import desc, asc, Label
@@ -386,3 +388,65 @@ def render_statement(statement, bind=None):
             return super(Compiler, self).render_literal_value(value, type_)
 
     return Compiler(bind.dialect, statement).process(statement)
+
+
+def batch_fetch(entities, attr):
+    """
+    Batch fetch given relationship attribute for collection of entities.
+
+    This function is in many cases a valid alternative for SQLAlchemy's
+    subqueryload and performs lot better.
+
+    :param entities: list of entities of the same type
+    :param attr:
+        Either InstrumentedAttribute object or a string representing the name
+        of the instrumented attribute
+
+    Example::
+
+
+        from sqlalchemy_utils import batch_fetch
+
+
+        users = session.query(User).limit(20).all()
+
+        batch_fetch(users, User.phonenumbers)
+    """
+    if entities:
+        first = entities[0]
+        if isinstance(attr, six.string_types):
+            attr = getattr(
+                first.__class__, attr
+            )
+
+        prop = attr.property
+        if not isinstance(prop, RelationshipProperty):
+            raise Exception(
+                'Given attribute is not a relationship property.'
+            )
+
+        model = prop.mapper.class_
+        session = object_session(first)
+
+        if len(prop.remote_side) > 1:
+            raise Exception(
+                'Only relationships with single remote side columns are '
+                'supported.'
+            )
+
+        column_name = list(prop.remote_side)[0].name
+        parent_ids = [entity.id for entity in entities]
+
+        related_entities = (
+            session.query(model)
+            .filter(
+                getattr(model, column_name).in_(parent_ids)
+            )
+        )
+
+        parent_dict = dict((entity.id, []) for entity in entities)
+        for entity in related_entities:
+            parent_dict[getattr(entity, column_name)].append(entity)
+
+        for entity in entities:
+            set_committed_value(entity, prop.key, parent_dict[entity.id])
